@@ -38,6 +38,39 @@ class TestCase(testtools.TestCase):
             self.useFixture(fixtures.MonkeyPatch('sys.stderr', stderr))
 
 
+class HasManager(object):
+
+    def __init__(self, cls_name, attr_name):
+        self.cls_name = cls_name
+        self.attr_name = attr_name
+
+    def match(self, client):
+        if not hasattr(client, self.attr_name):
+            return ManagerClassMismatch(client, self.cls_name, self.attr_name)
+
+        obj = getattr(client, self.attr_name)
+        if (client.http_client != obj.api or
+           self.cls_name != obj.__class__.__name__):
+            return ManagerClassMismatch(client, self.cls_name, self.attr_name)
+        else:
+            return None
+
+
+class ManagerClassMismatch(object):
+
+    def __init__(self, client, cls_name, attr_name):
+        self.client = client
+        self.cls_name = cls_name
+        self.attr_name = attr_name
+
+    def describe(self):
+        return "Class %r mismatch for attribute %r on %r" % (
+            self.cls_name, self.attr_name, self.client)
+
+    def get_details(self):
+        return {}
+
+
 class CommandTestCase(TestCase):
     def setUp(self):
         super(CommandTestCase, self).setUp()
