@@ -21,11 +21,12 @@ COMMAND_MODULES = [
 
 
 def enhance_parser(parser, subparsers):
-    '''Take a basic (nonversioned) parser and enhance it with
+    """Take a basic (nonversioned) parser and enhance it with
     commands and options specific for this version of API.
 
-    :param parser: top level parser :param subparsers: top level
-        parser's subparsers collection where subcommands will go
-    '''
+    :param parser: top level parser
+    :param subparsers: top level parser's subparsers collection
+    where subcommands will go
+    """
     for command_module in COMMAND_MODULES:
         utils.define_commands_from_module(subparsers, command_module)
